@@ -166,7 +166,7 @@ out:
 }
 
 static void
-autorun_software_dialog_response (GtkDialog *dialog,
+autorun_software_dialog_response (AdwDialog *dialog,
                                   gchar     *response,
                                   GMount    *mount)
 {
